@@ -13,11 +13,22 @@ if(!isGeneric("LIST")) {
                function(from, ...) standardGeneric("LIST"))
 }
 
+if(!isGeneric("all_confidence")) {
+    setGeneric("all_confidence",
+               function(x, ...) standardGeneric("all_confidence"))
+}
+
 if(!isGeneric("decode")) {
     setGeneric("decode",
                function(x, ...) standardGeneric("decode"))
 }
 
+
+if(!isGeneric("hyperlift")) {
+    setGeneric("hyperlift",
+               function(x, ...) standardGeneric("hyperlift"))
+}
+
 if(!isGeneric("inspect"))
     setGeneric("inspect",
                function(x, ...) standardGeneric("inspect"))
@@ -92,6 +103,11 @@ if(!isGeneric("size")) {
                function(x) standardGeneric("size"))
 }
 
+if(!isGeneric("itemSupport")) {
+    setGeneric("itemSupport",
+               function(x, ...) standardGeneric("itemSupport"))
+}
+
 if(!isGeneric("subset")) {
     setGeneric("subset",
                function(x, ...) standardGeneric("subset"))
