@@ -256,7 +256,7 @@ static void _report_R (int *ids, int cnt, int supp, int *tal, void *data)
   Main Functions
 ----------------------------------------------------------------------*/
 
-SEXP reclat(SEXP x, SEXP y, SEXP parms, SEXP control)
+SEXP reclat(SEXP x, SEXP y, SEXP dim, SEXP parms, SEXP control)
 {
  	int i, l, k = 0, n = 0, maxcnt = 0;
 	INPUT   in;
@@ -399,7 +399,7 @@ SEXP reclat(SEXP x, SEXP y, SEXP parms, SEXP control)
   }
   t = clock();                  /* start the timer */
   if (param.verbose) Rprintf("Creating S4 object  ... ");
-  ans = PROTECT(returnObject(ruleset, &param));
+  ans = PROTECT(returnObject(ruleset, dim, &param));
   if (param.verbose) {
 	  Rprintf("done ");
 	  Rprintf("[%.2fs].\n", SEC_SINCE(t));
